@@ -6,13 +6,15 @@ with an I/O device.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-qdeviceio"
-__date__ = "14-09-2022"
-__version__ = "1.1.1"
+__date__ = "27-02-2023"
+__version__ = "1.2.0"
 # pylint: disable=protected-access
 
-from enum import IntEnum, unique
+import os
+import sys
 import queue
 import time
+from enum import IntEnum, unique
 
 # Code coverage tools 'coverage' and 'pytest-cov' don't seem to correctly trace
 # code which is inside methods called from within QThreads, see
@@ -27,28 +29,22 @@ from functools import wraps
 
 # Mechanism to support both PyQt and PySide
 # -----------------------------------------
-import os
-import sys
 
-QT_LIB = os.getenv("PYQTGRAPH_QT_LIB")
-PYSIDE = "PySide"
-PYSIDE2 = "PySide2"
-PYSIDE6 = "PySide6"
-PYQT4 = "PyQt4"
 PYQT5 = "PyQt5"
 PYQT6 = "PyQt6"
+PYSIDE2 = "PySide2"
+PYSIDE6 = "PySide6"
+QT_LIB_ORDER = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
+QT_LIB = None
 
-# pylint: disable=import-error, no-name-in-module
-# fmt: off
 if QT_LIB is None:
-    libOrder = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
-    for lib in libOrder:
+    for lib in QT_LIB_ORDER:
         if lib in sys.modules:
             QT_LIB = lib
             break
 
 if QT_LIB is None:
-    for lib in libOrder:
+    for lib in QT_LIB_ORDER:
         try:
             __import__(lib)
             QT_LIB = lib
@@ -57,11 +53,14 @@ if QT_LIB is None:
             pass
 
 if QT_LIB is None:
-    raise Exception(
-        "DvG_QDeviceIO requires PyQt5, PyQt6, PySide2 or PySide6; none of "
-        "these packages could be imported."
+    this_file = __file__.split(os.sep)[-1]
+    raise ImportError(
+        f"{this_file} requires PyQt5, PyQt6, PySide2 or PySide6; "
+        "none of these packages could be imported."
     )
 
+# fmt: off
+# pylint: disable=import-error, no-name-in-module
 if QT_LIB == PYQT5:
     from PyQt5 import QtCore                               # type: ignore
     from PyQt5.QtCore import pyqtSlot as Slot              # type: ignore
@@ -78,9 +77,9 @@ elif QT_LIB == PYSIDE6:
     from PySide6 import QtCore                             # type: ignore
     from PySide6.QtCore import Slot                        # type: ignore
     from PySide6.QtCore import Signal                      # type: ignore
-
-# fmt: on
 # pylint: enable=import-error, no-name-in-module
+# fmt: on
+
 # \end[Mechanism to support both PyQt and PySide]
 # -----------------------------------------------
 
